fhirpack.custom.transformation package — fhirpack 0.0.2b0 documentation

# fhirpack.custom.transformation package

## Submodules

## fhirpack.custom.transformation.base module

class fhirpack.custom.transformation.base.PluginBaseTransformerMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.transformation.base', 'unimplementedPluginBaseTransformerMethod': <function PluginBaseTransformerMixin.unimplementedPluginBaseTransformerMethod>, '__dict__': <attribute '__dict__' of 'PluginBaseTransformerMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginBaseTransformerMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.transformation.base'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginBaseTransformerMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## fhirpack.custom.transformation.sample module

class fhirpack.custom.transformation.sample.PluginSampleTransformerMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.transformation.sample', 'unimplementedPluginSampleTransformerMethod': <function PluginSampleTransformerMixin.unimplementedPluginSampleTransformerMethod>, '__dict__': <attribute '__dict__' of 'PluginSampleTransformerMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginSampleTransformerMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.transformation.sample'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginSampleTransformerMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## Module contents

class fhirpack.custom.transformation.PluginTransformerMixin

  Bases: `PluginBaseTransformerMixin`, `PluginSampleTransformerMixin`

  __doc__ = None
  __module__ = 'fhirpack.custom.transformation'